Legals — mosaik 2.3.1 documentation

# Legals

Address

OFFIS e. V.
Escherweg 2
26121 Oldenburg
Germany
Phone +49 441 9722-0
Fax +49 441 9722-102
Email: institut [ A T ] offis.de
Internet: www.offis.de

Board Members

Prof. Dr.-Ing. Wolfgang H. Nebel (Chairman)
Prof. Dr. techn. Susanne Boll-Westermann
Prof. Dr. Werner Damm
Prof. Dr.-Ing. Andreas Hein
Prof. Dr. Sebastian Lehnhoff

Register Court

Amtsgericht Oldenburg
Registernumber VR 1956

VAT Identification Number

DE 811582102

Responsible in the sense of § 55 RStV

Dr. Christoph Mayer (Director)
OFFIS e.V.
Escherweg 2
26121 Oldenburg

Disclaimer

Despite careful control OFFIS assumes no liability for the content of external links. The operators of such a website are solely responsible for its content. At the time of linking the concerned sites were checked for possible violations of law. Illegal contents were not identifiable at that time. A permanent control of the linked pages is not reasonable without specific indications of a violation. Upon notification of violations, OFFIS will remove such links immediately.